@@ -78,10 +78,12 @@ def test_algebraic_constraints_function(minimizer):
 
 def test_constraints_function_call():
     """Test a constraint with simple function call in Model class."""
-    x = [1723, 1773, 1823, 1523, 1773, 1033.03078, 1042.98077, 1047.90937,
-         1053.95899, 1057.94906, 1063.13788, 1075.74218, 1086.03102]
-    y = [0.79934, -0.31876, -0.46852, 0.05, -0.21, 11.1708, 10.31844, 9.73069,
-         9.21319, 9.12457, 9.05243, 8.66407, 8.29664]
+
+    x = np.array([1723, 1773, 1823, 1523, 1773, 1033.03078, 1042.98077,
+                  1047.90937, 1053.95899, 1057.94906, 1063.13788, 1075.74218,
+                  1086.03102])
+    y = np.array([0.79934, -0.31876, -0.46852, 0.05, -0.21, 11.1708, 10.31844,
+                  9.73069, 9.21319, 9.12457, 9.05243, 8.66407, 8.29664])
 
     def VFT(T, ninf=-3, A=5e3, T0=800):
         return ninf + A/(T-T0)
