@@ -11,9 +11,9 @@ from scipy import __version__ as scipy_version
 
 import lmfit
 from lmfit import Model, Parameters, models
-from lmfit.lineshapes import gaussian, lorentzian
+from lmfit.lineshapes import gaussian, lorentzian, step, voigt
 from lmfit.model import get_reducer, propagate_err
-from lmfit.models import GaussianModel, PseudoVoigtModel
+from lmfit.models import GaussianModel, PseudoVoigtModel, QuadraticModel
 
 
 @pytest.fixture()
@@ -202,11 +202,22 @@ def test_Model_get_state(gmodel):
 
     assert isinstance(out, tuple)
     assert out[1] == out[2] is None
-    assert (out[0][1] is not None) == lmfit.jsonutils.HAS_DILL
-
-    assert out[0][0] == 'gaussian'
-    assert out[0][2:] == ('gaussian', '', ['x'],
-                          ['amplitude', 'center', 'sigma'], {}, 'raise', {})
+    sstate = out[0]
+    if isinstance(sstate, tuple):  # state version 1
+        assert sstate[1] is not None
+        assert sstate[0] == 'gaussian'
+        assert sstate[2:] == ('gaussian', '', ['x'],
+                              ['amplitude', 'center', 'sigma'], {}, 'raise', {})
+    elif isinstance(sstate, dict) and 'version' in sstate:  # state version 2 or higher
+        if sstate['version'] == '2':
+            assert sstate['funcname'] == 'gaussian'
+            assert sstate['name'] == 'gaussian'
+            assert sstate['independent_vars'] == ['x']
+            assert sstate['param_root_names'] == ['amplitude', 'center', 'sigma']
+        else:
+            assert sstate['version'] == 'unknown version!'
+    else:
+        assert sstate == 'unknown model state'
 
 
 def test_Model_set_state(gmodel):
@@ -270,7 +281,7 @@ def test_Model_getter_param_names(gmodel):
 
 def test_Model__repr__(gmodel):
     """Test for Model class __repr__ method."""
-    assert gmodel.__repr__() == '<lmfit.Model: Model(gaussian)>'
+    assert 'Model(gaussian)' in gmodel.__repr__()
 
 
 def test_Model_copy(gmodel):
@@ -864,7 +875,45 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
     def test_missing_independent_variable_raises_error(self):
         pars = self.model.make_params(**self.guess())
         f = lambda: self.model.fit(self.data, pars)
-        self.assertRaises(KeyError, f)
+        self.assertRaises(ValueError, f)
+
+    def test_independent_var_parsing(self):
+        """test the parsing of independent variables for model functions
+        with keyword arguments
+
+        step:  form='linear'
+        voigt: gamma=None,     can become a variable!!
+        """
+        stepmod1 = Model(step)
+        assert 'x' in stepmod1.independent_vars
+        assert 'form' in stepmod1.independent_vars
+        assert 'linear' == stepmod1.independent_vars_defvals.get('form', None)
+
+        stepmod2 = Model(step, form='arctan')
+        assert 'x' in stepmod2.independent_vars
+        assert 'form' in stepmod2.independent_vars
+        assert 'arctan' == stepmod2.independent_vars_defvals.get('form', None)
+
+        x = np.linspace(0, 30, 301)
+        pars = stepmod1.make_params(amplitude=10, center=14, sigma=2.5)
+        yline = stepmod1.eval(pars, x=x)
+        yatan = stepmod2.eval(pars, x=x)
+
+        assert (yatan-yline).std() > 0.1
+        assert np.ptp(yatan-yline) > 1.0
+
+        voigtmod = Model(voigt)
+        assert 'x' in voigtmod.independent_vars
+        assert 'gamma' in voigtmod.independent_vars
+        assert voigtmod.independent_vars_defvals['gamma'] is None
+
+        pars1 = voigtmod.make_params(amplitude=25, center=9.5, sigma=1)
+        assert 'sigma' in pars1
+        assert 'gamma' not in pars1
+
+        pars2 = voigtmod.make_params(amplitude=25, center=9.5, sigma=1, gamma=0.5)
+        assert 'sigma' in pars2
+        assert 'gamma' in pars2
 
     def test_bounding(self):
         true_values = self.true_values()
@@ -1079,6 +1128,10 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
     def test_composite_plotting(self):
         # test that a composite model has non-empty best_values
         import matplotlib
+        try:
+            matplotlib.pyplot.close('all')
+        except ValueError:
+            pass
         matplotlib.use('Agg')
 
         model1 = models.GaussianModel(prefix='g1_')
@@ -1535,3 +1588,141 @@ def test_compositemodel_returning_list():
     pars.add('m2_k', value=0.5)
     result = ModelSum.fit(y, pars, x=x)
     assert len(result.best_fit) == len(x)
+
+
+def test_rsquared_with_weights():
+    """Github #921"""
+    def func(x, k=1, b=0):
+        return k*x+b
+
+    x = np.array([1, 2, 3, 4])
+    y = np.array([1.1, 1.9, 3.05, 3.95])
+    yerr = np.array([0.03, 0.04, 0.01, 0.02])
+
+    mod = Model(func)
+    params = mod.make_params()
+    result = mod.fit(y, params, x=x, weights=1.0/yerr)
+
+    assert result.rsquared < 1.00
+    assert result.rsquared > 0.95
+
+
+# based on Github #953
+class PolynomialFunction:
+    def __init__(self, degree=1):
+        self.degree = degree
+
+    @property
+    def __name__(self):
+        return self.__class__.__name__
+
+    @property
+    def argnames(self):
+        return ["x"] + [f"c{i}" for i in range(self.degree + 1)]
+
+    @property
+    def kwargs(self):
+        return {}
+
+    def __call__(self, x, *coeffs, **params):
+        if len(coeffs) != self.degree + 1:
+            coeffs = [params[f"c{d}"] for d in range(self.degree + 1)]
+        return np.polynomial.polynomial.polyval(x, coeffs)
+
+
+def test_custom_variadic_model():
+    """Github #953"""
+    model = Model(PolynomialFunction(degree=3))
+    params = model.make_params(c0=5, c1=3.6, c2=-0.2, c3=0)
+
+    assert 'x' in model.independent_vars
+
+    np.random.seed(0)
+    x1 = np.linspace(-10, 10, 201)
+    y1 = 5 + 3.3*x1 + 0.17*x1**2 - 0.004*x1**3
+    y1 += np.random.normal(size=201, scale=0.1)
+
+    result = model.fit(y1, params, x=x1)
+
+    assert result.chisqr < 15.0
+    assert result.nfev > 7
+    assert_allclose(result.values['c0'], 5.0, 0.02, 0.02, '', True)
+    assert_allclose(result.values['c1'], 3.3, 0.02, 0.02, '', True)
+
+
+def test_model_refitting():
+    """Github #960"""
+    np.random.seed(0)
+    x = np.linspace(0, 100, 5001)
+    y = gaussian(x, amplitude=90, center=60, sigma=4) + 30 + 0.3*x - 0.0030*x*x
+    y += np.random.normal(size=5001, scale=0.5)
+
+    model = GaussianModel(prefix='peak_') + QuadraticModel(prefix='bkg_')
+
+    params = model.make_params(bkg_a=0, bkg_b=0, bkg_c=20, peak_amplitude=200,
+                               peak_center=55, peak_sigma=10)
+
+    result = model.fit(y, params, x=x, method='powell')
+    assert result.chisqr > 12000.0
+    assert result.nfev > 500
+    assert result.params['peak_amplitude'].value > 500
+    assert result.params['peak_amplitude'].value < 5000
+    assert result.params['peak_sigma'].value > 10
+    assert result.params['peak_sigma'].value < 100
+
+    # now re-fit with LM
+    result.fit(y, x=x, method='leastsq')
+
+    assert result.nfev > 25
+    assert result.nfev < 200
+    assert result.chisqr < 2000.0
+
+    assert result.params['peak_amplitude'].value > 85
+    assert result.params['peak_amplitude'].value < 95
+    assert result.params['peak_sigma'].value > 3
+    assert result.params['peak_sigma'].value < 5
+
+    # and assert that the initial value are from the Powell result
+    assert result.init_values['peak_amplitude'] > 1500
+    assert result.init_values['peak_sigma'] > 25
+
+    params = model.make_params(bkg_a=0, bkg_b=-.02, bkg_c=26, peak_amplitude=20,
+                               peak_center=62, peak_sigma=3)
+
+    # now re-fit with LM and these new params
+    result.fit(y, params, x=x, method='leastsq')
+
+    # and assert that the initial value are from the Powell result
+    assert result.init_values['peak_amplitude'] > 19
+    assert result.init_values['peak_amplitude'] < 21
+    assert result.init_values['peak_sigma'] > 2
+    assert result.init_values['peak_sigma'] < 4
+
+
+def test_model_barestar():
+    """Github #976 (and discussion #975)"""
+    def foo(x, *, a=1, b=1, kind='linear'):
+        if kind == 'linear':
+            return a + b * x
+        elif kind == 'exponential':
+            return a * np.exp(b * x)
+
+    modl = lmfit.Model(foo)
+    assert modl.independent_vars == ['x', 'kind']
+    assert modl._param_names == ['a', 'b']
+
+
+def test_model_bareslash():
+    """Github #976 (and discussion #975)"""
+    def foo(x, /, a=1, b=1, kind='linear'):
+        if kind == 'linear':
+            return a + b * x
+        elif kind == 'exponential':
+            return a * np.exp(b * x)
+    try:
+        lmfit.Model(foo)
+        that_failed = False
+    except ValueError:
+        that_failed = True
+
+    assert that_failed
