@@ -9,12 +9,11 @@ from numpy.testing import assert_allclose
 import pytest
 
 from lmfit import Parameters
-import lmfit.jsonutils
 from lmfit.lineshapes import gaussian, lorentzian
 from lmfit.model import (Model, ModelResult, load_model, load_modelresult,
                          save_model, save_modelresult)
 from lmfit.models import (ExponentialModel, ExpressionModel, GaussianModel,
-                          VoigtModel)
+                          SplineModel, VoigtModel)
 
 y, x = np.loadtxt(os.path.join(os.path.dirname(__file__), '..',
                                'examples', 'NIST_Gauss2.dat')).T
@@ -89,14 +88,8 @@ def check_fit_results(result):
     assert_allclose(pars['g2_height'], 72.045593, rtol=1.0e-5)
 
 
-@pytest.mark.parametrize("dill", [False, True])
-def test_save_load_model(dill):
-    """Save/load Model with/without dill."""
-    if dill:
-        pytest.importorskip("dill")
-    else:
-        lmfit.jsonutils.HAS_DILL = False
-
+def test_save_load_model():
+    """Save/load Model, now always asserting that dill is available."""
     # create/save Model and perform some tests
     model, _pars = create_model_params(x, y)
     save_model(model, SAVE_MODEL)
@@ -128,14 +121,8 @@ def test_save_load_model(dill):
     clear_savefile(SAVE_MODEL)
 
 
-@pytest.mark.parametrize("dill", [False, True])
-def test_save_load_modelresult(dill):
-    """Save/load ModelResult with/without dill."""
-    if dill:
-        pytest.importorskip("dill")
-    else:
-        lmfit.jsonutils.HAS_DILL = False
-
+def test_save_load_modelresult():
+    """Save/load ModelResult now always asserting that dill is available."""
     # create model, perform fit, save ModelResult and perform some tests
     model, params = create_model_params(x, y)
     result = model.fit(y, params, x=x)
@@ -147,7 +134,7 @@ def test_save_load_modelresult(dill):
     text = ''
     with open(SAVE_MODELRESULT) as fh:
         text = fh.read()
-    assert 12000 < len(text) < 60000  # depending on whether dill is present
+    assert 12000 < len(text) < 60000
 
     # load the saved ModelResult from file and compare results
     result_saved = load_modelresult(SAVE_MODELRESULT)
@@ -230,6 +217,62 @@ def test_saveload_modelresult_roundtrip(method):
     assert_allclose(result3.params['b'], 0.22, rtol=1.0e-2)
 
 
+def test_saveload_modelresult_roundtrip_user_expr_function():
+    """Test for modelresult.loads()/dumps() for a model with user defined expr function."""
+
+    def mfunc(x, a, b):
+        return a * (x-b)
+
+    def expr_func(x):
+        return 3 * x
+
+    model = Model(mfunc)
+    params = Parameters(usersyms={"expr_func": expr_func})
+    params.add("a", min=.01, max=1)
+    params.add("b", min=.01, max=3.1)
+    params.add("c", expr="expr_func(a)")
+
+    np.random.seed(2020)
+    xx = np.linspace(-5, 5, 201)
+    yy = 0.5 * (xx - 0.22) + np.random.normal(scale=0.01, size=xx.size)
+
+    result1 = model.fit(yy, params=params, x=xx)
+
+    result2 = ModelResult(model, Parameters())
+    result2.loads(result1.dumps(), funcdefs={'mfunc': mfunc, 'expr_func': expr_func})
+
+    assert result1.userfcn == result2.userfcn
+    assert result1.params == result2.params
+    assert result1.init_params == result2.init_params
+    assert set(result1.params._asteval.symtable) == set(result2.params._asteval.symtable)
+
+
+def test_saveload_modelresult_eval_uncertainty():
+    """Test for ModelResult.loads() and eval_uncertainty
+    GH Issue #909
+
+    """
+    savefile = 'modres_x.txt'
+    x = np.linspace(-10, 10, 201)
+    amp, cen, wid = 3.4, 1.8, 0.5
+
+    y = amp * np.exp(-(x-cen)**2 / (2*wid**2)) / (np.sqrt(2*np.pi)*wid)
+    y += np.random.normal(size=x.size, scale=0.01)
+
+    gmod = GaussianModel()
+    result = gmod.fit(y, x=x, amplitude=5, center=2, sigma=1)
+    save_modelresult(result, savefile)
+    time.sleep(0.25)
+
+    result2 = load_modelresult(savefile)
+
+    dymod = result2.eval_uncertainty()
+
+    assert len(dymod) == len(x)
+    assert dymod.sum() > 0.
+    os.unlink(savefile)
+
+
 def test_saveload_modelresult_expression_model():
     """Test for ModelResult.loads()/dumps() for ExpressionModel.
 
@@ -258,6 +301,63 @@ def test_saveload_modelresult_expression_model():
     os.unlink(savefile)
 
 
+def test_saveload_modelresult_spline_model(tmp_path):
+    """Test for ModelResult.loads()/dumps() for Spline Model.
+
+    The spline model is a special case with a possibly indefinite
+    amount of arguments. This is a problem for model parsing and
+    as a workaround, the number of knots was increased to 100 as
+    discussed in https://github.com/lmfit/lmfit-py/issues/985.
+    """
+    number_of_knots = 80
+    model_file = tmp_path / 'spline_modelresult.sav'
+    xx = np.linspace(-10, 10, 100)
+    yy = 0.6*np.exp(-(xx**2)/(1.3**2))
+
+    spl_model = SplineModel(xknots=np.linspace(-10, 10, number_of_knots))
+    params = spl_model.guess(yy, xx)
+    result = spl_model.fit(yy, params, x=xx)
+
+    save_modelresult(result, model_file)
+
+    time.sleep(0.25)
+
+    result2 = load_modelresult(model_file)
+
+    # accuracy of storing data should be above 12 decimals
+    assert_allclose(result.residual, result2.residual, rtol=0, atol=1e-12)
+    assert_allclose(list(result.best_values.values()),
+                    list(result2.best_values.values()),
+                    rtol=0, atol=1e-12)
+    assert_allclose(list(result.init_values.values()),
+                    list(result2.init_values.values()),
+                    rtol=0, atol=1e-12)
+    assert_allclose(list(result.values.values()),
+                    list(result2.values.values()),
+                    rtol=0, atol=1e-12)
+    assert_allclose(result.covar, result2.covar, rtol=0, atol=1e-12)
+    assert_allclose(result.userargs[0], result2.userargs[0],
+                    rtol=0, atol=1e-12)
+    assert_allclose(result.userkws["x"], result2.userkws["x"],
+                    rtol=0, atol=1e-12)
+    for attr in ('best_fit', 'init_fit'):
+        val1 = getattr(result, attr)
+        val2 = getattr(result2, attr)
+        assert_allclose(val1.mean(), val2.mean(), rtol=0.01, atol=0.01)
+
+    for attr in ['aborted', 'aic', 'bic', 'chisqr', 'ci_out', 'col_deriv',
+                 'errorbars', 'flatchain', 'ier', 'lmdif_message', 'message',
+                 'method', 'nan_policy', 'ndata', 'nfev', 'nfree', 'nvarys',
+                 'redchi', 'rsquared', 'scale_covar', 'calc_covar', 'success',
+                 'var_names', 'weights', 'user_options']:
+        val1 = getattr(result, attr)
+        val2 = getattr(result2, attr)
+        if val1 is None:
+            assert val2 is None
+        else:
+            assert val1 == val2
+
+
 def test_saveload_usersyms():
     """Test save/load of ModelResult with non-trivial user symbols.
 
@@ -316,3 +416,27 @@ def test_modelresult_summary():
         assert val != '__INVALID__'
 
     assert len(json.dumps(summary)) > 100
+
+
+def test_load_model_versions():
+    """test multiple loading saved models from different
+    python and lmfit versions:
+
+    note that providing the model function is important - these
+    cannot be transferred between Python versions
+    """
+    def local_sine(x, amp, freq, shift):
+        return amp * np.sin(x*freq + shift)
+
+    x = np.linspace(0, 10, 101)
+
+    for fname in ('sinemodel_py310_lm122.sav',
+                  'sinemodel_py311_lm122.sav',
+                  'sinemodel_py312_lm122.sav'):
+        fpath = os.path.join(os.path.dirname(__file__), 'saved_models', fname)
+
+        mod = load_model(fpath, funcdefs={'mysine': local_sine})
+        pars = mod.make_params(amp=2, freq=0.8, shift=0.200)
+        y = mod.eval(pars, x=x)
+        assert y.max() > 1.55
+        assert y.min() < -1.55
